#
#       config.py
#       
#       Copyright 2009 Andrew <rugby471@gmail.com>
#       
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 2 of the License, or
#       (at your option) any later version.
#       
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#       
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.

import os
import logging
from ConfigParser import SafeConfigParser
from gettext import gettext as _


class MeMakerConfig:
    def __init__(self, config_directory, theme_directory):
        self.config_directory = config_directory
        
        if not os.path.isfile(os.path.join(config_directory, "conf.conf")):
            logging.info(_("Creating conf.conf with default theme."))
            self.memaker_configuration = SafeConfigParser()
            self.memaker_configuration.add_section('main')
            default_theme_location = os.path.join(theme_directory, 
                                                    "cocoHead")
            self.memaker_configuration.set('main', 'lastTheme', 
                                            default_theme_location)
            self.memaker_configuration.set('main', 'launchpadAuth', 
                                            "False")
            self.memaker_configuration_file = open(os.path.join(
                                                self.config_directory, 
                                                "conf.conf"), 'w')
            self.memaker_configuration.write(self.memaker_configuration_file)
            self.memaker_configuration_file.close()
        
    def open(self):
        self.memaker_configuration = SafeConfigParser()
        self.memaker_configuration.read(os.path.join(
                                        self.config_directory,
                                        "conf.conf"))

        
    def set_key(self, section, keyname, value):
        self.open()
        self.memaker_configuration.set(section, keyname, value)
        self.memaker_configuration_file = open(os.path.join(
                                                self.config_directory, 
                                                "conf.conf"), 'w')
        self.memaker_configuration.write(self.memaker_configuration_file)
        self.memaker_configuration_file.close()
        
    def get_key(self, section, keyname):
        self.open()
        value = self.memaker_configuration.get(section, keyname)
        return value
        
