#
#       libpurple.py
#       
#       Copyright 2009 Andrew <rugby471@gmail.com>
#       
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 2 of the License, or
#       (at your option) any later version.
#       
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#       
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.

import os
import gtk
import pango

from xml.etree import ElementTree as ET

from gettext import gettext as _

class PidginParse:
    def __init__(self, pidgin_dir, pidgin_icons_dir):
        self.pidgin_dir = pidgin_dir
        self.pidgin_icons_dir = pidgin_icons_dir
        self.file = ET.parse(os.path.join(self.pidgin_dir, "accounts.xml"))
        self.root = self.file.getroot()
        self.account_types = []
        self.account_names = []
        self.account_icons = []
        for account in self.root.getchildren():
            for tag in account.getchildren():
                if tag.tag == "protocol":
                    if len(tag.text.replace("prpl-", "").capitalize()) == 3:
                        type = tag.text.replace("prpl-", "").upper()
                    else:
                        type = tag.text.replace("prpl-", "").capitalize()
                    self.account_types.append(type)
                if tag.tag == "name":
                    self.account_names.append(tag.text)
                if tag.tag == "settings":
                    for subtag in tag.getchildren():
                        if subtag.tag == "setting" and subtag.get("name") == "buddy_icon":
                            self.account_icons.append(subtag.text)
                            
    def remove_old_avatars(self):
        # remove old memaker avatars that are not used
        for file in os.listdir(self.pidgin_icons_dir):
            if file.startswith('memaker') and os.path.isfile(os.path.join(self.pidgin_icons_dir, file)) and (file not in self.account_icons):
                os.remove(os.path.join(self.pidgin_icons_dir, file))
                
    def return_values(self):
        return (self.account_types, self.account_names, self.account_icons)
        
    def set_values(self, values, data):
        for ind in values:
            tags = self.root.getchildren()[ind]
            for tag in tags:
                if tag.tag == "settings":
                    for subtag in tag.getchildren():
                        if subtag.tag == "setting" and \
                            subtag.get("name") == "buddy_icon":
                            subtag.text = data
                        if subtag.tag == "setting" and \
                            subtag.get("name") == "use-global-buddyicon":
                            subtag.text = "0"
        self.file.write(os.path.join(self.pidgin_dir, "accounts.xml"))
        

class MeMakerPidginStore(gtk.ListStore):
    def __init__(self, pidgin_icons_dir, values):
        gtk.ListStore.__init__(self, gtk.gdk.Pixbuf, str)
        (account_types, account_names, account_icons) = values
        
        for account_type in account_types:
            account_name = account_names[account_types.index(account_type)]
            account_icon = account_icons[account_types.index(account_type)]
            pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(
                    os.path.join(pidgin_icons_dir, account_icon), 
                    32, 32)
            self.append([pixbuf, "%s\n<small>%s</small>" % (account_name, account_type)])
    
    
class MeMakerPidginTreeView(gtk.TreeView):
    def __init__(self, pidgin_dir, pidgin_icons_dir):
        parse = PidginParse(pidgin_dir, pidgin_icons_dir)
        parse.remove_old_avatars()
        list_store = MeMakerPidginStore(pidgin_icons_dir, parse.return_values())
        
        gtk.TreeView.__init__(self)
        
        tp = gtk.CellRendererPixbuf()
        column = gtk.TreeViewColumn("Icon", tp, pixbuf=0)
        column.set_fixed_width(40)
        column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
        self.append_column(column)
        list = ["Type", "Name"]
        tr = gtk.CellRendererText()
        tr.set_property("ellipsize", pango.ELLIPSIZE_MIDDLE)
        column = gtk.TreeViewColumn("Name",tr, markup=1)
        column.set_fixed_width(200)
        column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
        self.append_column(column)
        
        self.set_property("headers-visible", False)
        self.set_property("rubber-banding", True)
        self.get_selection().set_mode(gtk.SELECTION_MULTIPLE)
        self.set_model(list_store)
